# New in 0.11.0 (2021-05-23)

From the user perspective, this release features the new differential expression functionality (to be described in a manuscript). For now, it is accessible from {func}`~scvi.model.SCVI.differential_expression`. From the developer perspective, we made changes with respect to {class}`scvi.dataloaders.DataSplitter` and surrounding the Pyro backend. Finally, we also made changes to adapt our code to PyTorch Lightning version 1.3.

## Changes

-   Pass `n_labels` to {class}`~scvi.module.VAE` from {class}`~scvi.model.SCVI` ([#1055]).
-   Require PyTorch lightning > 1.3, add relevant fixes ([#1054]).
-   Add DestVI reference ([#1060]).
-   Add PeakVI links to README ([#1046]).
-   Automatic delta and eps computation in differential expression ([#1043]).
-   Allow doublet ratio parameter to be changed for used in SOLO ([#1066]).

## Bug fixes

-   Fix an issue where `transform_batch` options in {class}`~scvi.model.TOTALVI` was accidentally altering the batch encoding in the encoder, which leads to poor results ([#1072]). This bug was introduced in version 0.9.0.

## Breaking changes

These breaking changes do not affect the user API; though will impact model developers.

-   Use PyTorch Lightning data modules for {class}`scvi.dataloaders.DataSplitter` ([#1061]). This induces a breaking change in the way the data splitter is used. It is no longer callable and now has a `setup` method. See {class}`~scvi.train.TrainRunner` and its source code, which is straightforward.
-   No longer require training plans to be initialized with `n_obs_training` argument ([#1061]). `n_obs_training` is now a property that can be set before actual training to rescale the loss.
-   Log Pyro loss as `train_elbo` and sum over steps ([#1071])

## Contributors

-   [@adamgayoso]
-   [@romain-lopez]
-   [@PierreBoyeau]
-   [@talashuach]
-   [@cataclysmus]
-   [@njbernstein]

[#1043]: https://github.com/YosefLab/scvi-tools/pull/1043
[#1046]: https://github.com/YosefLab/scvi-tools/pull/1046
[#1054]: https://github.com/YosefLab/scvi-tools/pull/1054
[#1055]: https://github.com/YosefLab/scvi-tools/pull/1055
[#1060]: https://github.com/YosefLab/scvi-tools/pull/1060
[#1061]: https://github.com/YosefLab/scvi-tools/pull/1061
[#1066]: https://github.com/YosefLab/scvi-tools/pull/1066
[#1071]: https://github.com/YosefLab/scvi-tools/pull/1071
[#1072]: https://github.com/YosefLab/scvi-tools/pull/1072
[@adamgayoso]: https://github.com/adamgayoso
[@cataclysmus]: https://github.com/cataclysmus
[@njbernstein]: https://github.com/njbernstein
[@pierreboyeau]: https://github.com/PierreBoyeau
[@romain-lopez]: https://github.com/romain-lopez
[@talashuach]: https://github.com/talashuach
